@@ -15,6 +15,7 @@ from motus import funciones_auxiliares as fa
 from motus import regiones_preferidas as rp
 from motus.fisica_estadistica import histogramas as m_hist, analisis_regresion_lineal as arl
 from motus.fisica_estadistica import entropia_divergencia as m_ed
+import motus.graficador.config_graficas as m_cg
 from motus.graficador import cilindros
 
 warnings.filterwarnings("error")
@@ -37,8 +38,6 @@ class Experimento:
         self.lista_ordenada_de_indices_mas_altos = None
         self.archivo_consecuencias = False
 
-        self.config_graficas = ConfigGraficas()
-
         self.entropias = dict()
         self.histogramas = dict()
 
@@ -150,6 +149,11 @@ class Experimento:
             print("self.consecuencias: ", self.consecuencias)
             print(np.where(self.consecuencias == 1)[0])
 
+            self.config_graficas.columna_consecuencia_disponible = True
+            self.config_graficas.lista_consecuencias = np.where(self.consecuencias == 1)[0]
+        else:
+            self.config_graficas.columna_consecuencia_disponible = False
+
         self.valor_intervalos_tiempo = arreglo_tiempo.iloc[1] - arreglo_tiempo.iloc[0]
 
         print("Procesar tiempo irregular: ", procesar_tiempo_archivo_irregular)
@@ -1110,6 +1114,8 @@ class Experimento:
         #    plt.legend()
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada':
+            if self.matriz_recurrencia_region_cuadriculada is None:
+                self.calcula_regiones_cuadriculadas()
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
@@ -1117,8 +1123,6 @@ class Experimento:
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_1':
 
             plt.grid(False)
-            plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
-                       interpolation='nearest', vmin=-1, vmax=0)
             plt.imshow(-1 * self.matriz_recurrencia_objeto_1, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
